==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/mixer/adapter/prometheus/LinearBucketsDefinitionFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.prometheus;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Double;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class LinearBucketsDefinitionFluentImpl<A extends LinearBucketsDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements LinearBucketsDefinitionFluent<A>{

    private LinearBuilder linearBuckets;

    public LinearBucketsDefinitionFluentImpl(){
    }
    public LinearBucketsDefinitionFluentImpl(LinearBucketsDefinition instance){
            this.withLinearBuckets(instance.getLinearBuckets()); 
    }

    
/**
 * This method has been deprecated, please use method buildLinearBuckets instead.
 * @return The buildable object.
 */
@Deprecated public Linear getLinearBuckets(){
            return this.linearBuckets!=null?this.linearBuckets.build():null;
    }

    public Linear buildLinearBuckets(){
            return this.linearBuckets!=null?this.linearBuckets.build():null;
    }

    public A withLinearBuckets(Linear linearBuckets){
            _visitables.remove(this.linearBuckets);
            if (linearBuckets!=null){ this.linearBuckets= new LinearBuilder(linearBuckets); _visitables.add(this.linearBuckets);} return (A) this;
    }

    public Boolean hasLinearBuckets(){
            return this.linearBuckets != null;
    }

    public A withNewLinearBuckets(Integer numFiniteBuckets,Double offset,Double width){
            return (A)withLinearBuckets(new Linear(numFiniteBuckets, offset, width));
    }

    public LinearBucketsDefinitionFluent.LinearBucketsNested<A> withNewLinearBuckets(){
            return new LinearBucketsNestedImpl();
    }

    public LinearBucketsDefinitionFluent.LinearBucketsNested<A> withNewLinearBucketsLike(Linear item){
            return new LinearBucketsNestedImpl(item);
    }

    public LinearBucketsDefinitionFluent.LinearBucketsNested<A> editLinearBuckets(){
            return withNewLinearBucketsLike(getLinearBuckets());
    }

    public LinearBucketsDefinitionFluent.LinearBucketsNested<A> editOrNewLinearBuckets(){
            return withNewLinearBucketsLike(getLinearBuckets() != null ? getLinearBuckets(): new LinearBuilder().build());
    }

    public LinearBucketsDefinitionFluent.LinearBucketsNested<A> editOrNewLinearBucketsLike(Linear item){
            return withNewLinearBucketsLike(getLinearBuckets() != null ? getLinearBuckets(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            LinearBucketsDefinitionFluentImpl that = (LinearBucketsDefinitionFluentImpl) o;
            if (linearBuckets != null ? !linearBuckets.equals(that.linearBuckets) :that.linearBuckets != null) return false;
            return true;
    }


    public class LinearBucketsNestedImpl<N> extends LinearFluentImpl<LinearBucketsDefinitionFluent.LinearBucketsNested<N>> implements LinearBucketsDefinitionFluent.LinearBucketsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final LinearBuilder builder;
    
            LinearBucketsNestedImpl(Linear item){
                    this.builder = new LinearBuilder(this, item);
            }
            LinearBucketsNestedImpl(){
                    this.builder = new LinearBuilder(this);
            }
    
    public N and(){
            return (N) LinearBucketsDefinitionFluentImpl.this.withLinearBuckets(builder.build());
    }
    public N endLinearBuckets(){
            return and();
    }

}


}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/mixer/adapter/prometheus/LinearBucketsDefinitionFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.prometheus;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Double;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class LinearBucketsDefinitionFluentImpl<A extends LinearBucketsDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements LinearBucketsDefinitionFluent<A>{

    private LinearBuilder linearBuckets;

    public LinearBucketsDefinitionFluentImpl(){
    }
    public LinearBucketsDefinitionFluentImpl(LinearBucketsDefinition instance){
            this.withLinearBuckets(instance.getLinearBuckets()); 
    }

    
/**
 * This method has been deprecated, please use method buildLinearBuckets instead.
 * @return The buildable object.
 */
@Deprecated public Linear getLinearBuckets(){
            return this.linearBuckets!=null?this.linearBuckets.build():null;
    }

    public Linear buildLinearBuckets(){
            return this.linearBuckets!=null?this.linearBuckets.build():null;
    }

    public A withLinearBuckets(Linear linearBuckets){
            _visitables.get("linearBuckets").remove(this.linearBuckets);
            if (linearBuckets!=null){ this.linearBuckets= new LinearBuilder(linearBuckets); _visitables.get("linearBuckets").add(this.linearBuckets);} return (A) this;
    }

    public Boolean hasLinearBuckets(){
            return this.linearBuckets != null;
    }

    public A withNewLinearBuckets(Integer numFiniteBuckets,Double offset,Double width){
            return (A)withLinearBuckets(new Linear(numFiniteBuckets, offset, width));
    }

    public LinearBucketsDefinitionFluent.LinearBucketsNested<A> withNewLinearBuckets(){
            return new LinearBucketsNestedImpl();
    }

    public LinearBucketsDefinitionFluent.LinearBucketsNested<A> withNewLinearBucketsLike(Linear item){
            return new LinearBucketsNestedImpl(item);
    }

    public LinearBucketsDefinitionFluent.LinearBucketsNested<A> editLinearBuckets(){
            return withNewLinearBucketsLike(getLinearBuckets());
    }

    public LinearBucketsDefinitionFluent.LinearBucketsNested<A> editOrNewLinearBuckets(){
            return withNewLinearBucketsLike(getLinearBuckets() != null ? getLinearBuckets(): new LinearBuilder().build());
    }

    public LinearBucketsDefinitionFluent.LinearBucketsNested<A> editOrNewLinearBucketsLike(Linear item){
            return withNewLinearBucketsLike(getLinearBuckets() != null ? getLinearBuckets(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            LinearBucketsDefinitionFluentImpl that = (LinearBucketsDefinitionFluentImpl) o;
            if (linearBuckets != null ? !linearBuckets.equals(that.linearBuckets) :that.linearBuckets != null) return false;
            return true;
    }


    public class LinearBucketsNestedImpl<N> extends LinearFluentImpl<LinearBucketsDefinitionFluent.LinearBucketsNested<N>> implements LinearBucketsDefinitionFluent.LinearBucketsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final LinearBuilder builder;
    
            LinearBucketsNestedImpl(Linear item){
                    this.builder = new LinearBuilder(this, item);
            }
            LinearBucketsNestedImpl(){
                    this.builder = new LinearBuilder(this);
            }
    
    public N and(){
            return (N) LinearBucketsDefinitionFluentImpl.this.withLinearBuckets(builder.build());
    }
    public N endLinearBuckets(){
            return and();
    }

}


}
